@@ -5,9 +5,17 @@ import sys
 
 
 def payload_to_zyte(spider_name):
-    if os.name == 'nt':
+    if os.name != 'nt':
+        data = sys.argv[1]
+        # print(data)
+        data = data.replace(',}', '}')
+        data = data.replace(',]', ']')
+        data = json.loads(data)
+        # print(data)
+
+    else:
         print("Windows Detected!, Please enter the payload again.")
-        data = input("Enter the JSON Payload (only): ")
+        data = input("Enter the JSON Payload with quotes (only): ")
         # print(data)
         data = data.replace(',}', '}')
         data = data.replace(',]', ']')
@@ -15,13 +23,6 @@ def payload_to_zyte(spider_name):
         data = data.replace("}'", "}")
         data = json.loads(data)
         # print(data)
-    else:
-        data = sys.argv[1]
-        # print(data)
-        data = data.replace(',}', '}')
-        data = data.replace(',]', ']')
-        data = json.loads(data)
-        # print(data)
 
     url = data['url']
     if 'actions' in data:
@@ -273,17 +274,17 @@ def main():
         args = sys.argv[1:]
         if "--help" in args:
             usage = '''
-    Usage: zyte_api_convertor <payload> --project-name <project_name> --spider-name <spider_name>
-    Example: zyte_api_convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}' --project-name sample_project --spider-name sample_spider
+    Usage: zyte-api-convertor <payload> --project-name <project_name> --spider-name <spider_name>
+    Example: zyte-api-convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}' --project-name sample_project --spider-name sample_spider
 
-    Usage: zyte_api_convertor <payload> --project-name <project_name>
-    Example: zyte_api_convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}' --project-name sample_project
+    Usage: zyte-api-convertor <payload> --project-name <project_name>
+    Example: zyte-api-convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}' --project-name sample_project
 
-    Usage: zyte_api_convertor <payload> --spider-name <spider_name>
-    Example: zyte_api_convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}' --spider-name sample_spider
+    Usage: zyte-api-convertor <payload> --spider-name <spider_name>
+    Example: zyte-api-convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}' --spider-name sample_spider
 
-    Usage: zyte_api_convertor <payload>
-    Example: zyte_api_convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}'
+    Usage: zyte-api-convertor <payload>
+    Example: zyte-api-convertor '{"url": "https://httpbin.org/ip", "browserHtml": true, "screenshot": true}'
             '''
             print(usage)
             return
@@ -335,6 +336,10 @@ def main():
                 print("Please provide a spider name.")
                 return
 
+        elif len(args) < 1:
+            print("Please provide a payload, Payload is Must. Use --help for more info")
+            return
+
         else:
             spider_name = "sample_zyte_api"
             code = payload_to_zyte(spider_name)
